@@ -26,7 +26,8 @@ class Handler(HandlerBase):
             description="Transform log into compact raw log containing only test results.",
             formatter_class=HelpFormatter)
 
-        parser.add_argument("--with-steps", action="store_true", help="include test steps, default: False")
+        parser.add_argument("--with-steps", action="store_true", help="include test steps, default: True", default=True)
+        parser.add_argument("--without-steps", action="store_true", help="exclude test steps, default: False", default=False)
         parser.add_argument("input", metavar="input", type=argtype.logfile("r", bufsize=1, encoding="utf-8"),
                 nargs="?", help="input log, default: stdin", default="-")
         parser.add_argument("output", metavar="output", type=argtype.logfile("w", bufsize=1, encoding="utf-8"),
@@ -35,4 +36,4 @@ class Handler(HandlerBase):
         parser.set_defaults(func=cls())
 
     def handle(self, args):
-        CompactRawLogPipeline(args.input, args.output, steps=args.with_steps).run()
+        CompactRawLogPipeline(args.input, args.output, steps=(not args.without_steps)).run()
